==> libgda-1.3.3.tar.bz2: libgda-1.3.3/providers/msql/gda-msql-recordset.h <==
/* GDA mSQL Provider
 * Copyright (C) 1998 - 2004 The GNOME Foundation
 *
 * AUTHORS:
 * 	   Danilo Schoeneberg <dj@starfire-programming.net
 *         Vivien Malerba <malerba@gnome-db.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __gda_msql_recordset_h__
#define __gda_msql_recordset_h__

#include <libgda/gda-connection.h>
#include <libgda/gda-data-model.h>
#include <libgda/gda-data-model-base.h>

G_BEGIN_DECLS

#define GDA_TYPE_MSQL_RECORDSET \
  (gda_msql_recordset_get_type())

#define GDA_MSQL_RECORDSET(o) \
  (G_TYPE_CHECK_INSTANCE_CAST(o,GDA_TYPE_MSQL_RECORDSET,GdaMsqlRecordset))

#define GDA_MSQL_RECORDSET_CLASS(cl) \
  (G_TYPE_CHECK_CLASS_CAST(cl,GDA_TYPE_MSQL_RECORDSET,GdaMsqlRecordsetClass))

#define GDA_IS_MSQL_RECORDSET(o) \
  (G_TYPE_CHECK_INSTANCE_TYPE(o,GDA_TYPE_MSQL_RECORDSET))

#define GDA_IS_MSQL_RECORDSET_CLASS(cl) \
  (G_TYPE_CHECK_CLASS_TYPE((cl),GDA_TYPE_MSQL_RECORDSET))

typedef struct _GdaMsqlRecordset      GdaMsqlRecordset;
typedef struct _GdaMsqlRecordsetClass GdaMsqlRecordsetClass;

struct _GdaMsqlRecordset {
	GdaDataModelBase model;
	GPtrArray       *rows;
	GdaConnection   *cnc;
	m_result        *res;
	int              sock;
	int              n_rows;
};

struct _GdaMsqlRecordsetClass {
	GdaDataModelBaseClass parent_class;
};

GType             gda_msql_recordset_get_type(void);
GdaMsqlRecordset *gda_msql_recordset_new(GdaConnection *cnc,m_result *res,
                                         int sock,int n_rows);

G_END_DECLS

#endif

==> libgda-1.9.103.tar.bz2: libgda-1.9.103/providers/msql/gda-msql-recordset.h <==
/* GDA mSQL Provider
 * Copyright (C) 1998 - 2004 The GNOME Foundation
 *
 * AUTHORS:
 * 	   Danilo Schoeneberg <dj@starfire-programming.net
 *         Vivien Malerba <malerba@gnome-db.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __gda_msql_recordset_h__
#define __gda_msql_recordset_h__

#include <libgda/gda-connection.h>
#include <libgda/gda-data-model.h>
#include <libgda/gda-data-model-row.h>

G_BEGIN_DECLS

#define GDA_TYPE_MSQL_RECORDSET \
  (gda_msql_recordset_get_type())

#define GDA_MSQL_RECORDSET(o) \
  (G_TYPE_CHECK_INSTANCE_CAST(o,GDA_TYPE_MSQL_RECORDSET,GdaMsqlRecordset))

#define GDA_MSQL_RECORDSET_CLASS(cl) \
  (G_TYPE_CHECK_CLASS_CAST(cl,GDA_TYPE_MSQL_RECORDSET,GdaMsqlRecordsetClass))

#define GDA_IS_MSQL_RECORDSET(o) \
  (G_TYPE_CHECK_INSTANCE_TYPE(o,GDA_TYPE_MSQL_RECORDSET))

#define GDA_IS_MSQL_RECORDSET_CLASS(cl) \
  (G_TYPE_CHECK_CLASS_TYPE((cl),GDA_TYPE_MSQL_RECORDSET))

typedef struct _GdaMsqlRecordset      GdaMsqlRecordset;
typedef struct _GdaMsqlRecordsetClass GdaMsqlRecordsetClass;

struct _GdaMsqlRecordset {
	GdaDataModelRow model;
	GPtrArray       *rows;
	GdaConnection   *cnc;
	m_result        *res;
	int              sock;
	int              n_rows;
};

struct _GdaMsqlRecordsetClass {
	GdaDataModelRowClass parent_class;
};

GType             gda_msql_recordset_get_type(void);
GdaMsqlRecordset *gda_msql_recordset_new(GdaConnection *cnc,m_result *res,
                                         int sock,int n_rows);

G_END_DECLS

#endif
